import React from 'react';
import { Button, Tabs, Form, Row, Col, InputNumber, message } from 'antd';
import useBool from '@/utils/hooks/useBool';
import { getTdLocType } from '@/service/tdloctype';
import { getByCheckId, postTaCheckItem } from '@/service/tacheckitem';
import QuManage from './QuManage';

const ItemForm = (props) => {
  const {checkId, typeId, onChange} = props;

  const [form] = Form.useForm();
  const [loading, startLoading, stopLoading] = useBool();

  const onFinish = (values) => {
    const data = {...values, checkId, typeId, itemType: 'loc'}

    startLoading();
    postTaCheckItem(data).then(res => {
      onChange(res);
      form.setFieldsValue(res);
      stopLoading();
    }).catch(() => {
      stopLoading();
    });
  }

  const reset = () => {
    form.resetFields();
    form.setFieldsValue({ num: 1 });
    onChange();
  }

  React.useEffect(() => {
    if (checkId && typeId) {
      startLoading();
      getByCheckId(checkId, typeId).then(res => {
        if (res) {
          onChange(res);
          form.setFieldsValue(res);
        } else {
          reset();
        }
        stopLoading();
      }).catch(() => {
        stopLoading();
        reset();
      });
    } else {
      reset();
    }
  }, [checkId, typeId]);

  return (
    <Form layout="inline" form={form} onFinish={onFinish}>
      <Form.Item label="数量" name="num">
        <InputNumber min={1} />
      </Form.Item>
      <Form.Item label="总分" name="fullScore">
        <InputNumber min={0.00} precision={2} />
      </Form.Item>
      <Form.Item>
        <Button disabled={!checkId || !typeId} loading={loading} type="primary" htmlType="submit">
          确定
        </Button>
      </Form.Item>
    </Form>
  )
}

export default React.forwardRef((props, ref) => {
  const {checkId} = props;
  const [locList, setLocList] = React.useState([]);
  const quRef = React.useRef();
  const [checkItem, setCheckItem] = React.useState();
  const [typeId, setTypeId] = React.useState();

  const tabItems = React.useMemo(() => {
    return locList.map(x => ({
      label: x.name,
      key: x.typeId,
    }));
  }, [locList]);

  React.useEffect(() => {
    getTdLocType({ pageSize: 500 }).then(res => {
      const list = res.records;
      setLocList(list);
      // 默认第一个
      setTypeId(list[0]?.typeId);
    });
  }, []);

  
  React.useImperativeHandle(ref, () => ({
    newQu: () => {
      if (!checkItem) {
        message.warning('请先设置数量, 总分等');
        return;
      }
      quRef.current.add();
    },
  }), [checkItem]);

  return (
    <div style={{display: 'flex'}}>
      <div style={{flex: 'none'}}>
        <Tabs
          tabPosition="left"
          activeKey={typeId}
          items={tabItems}
          onChange={(activeKey) => {
            setTypeId(activeKey)
            setCheckItem()
          }}
        />
      </div>
      <div style={{flex: 1}}>
        <ItemForm checkId={checkId} typeId={typeId} onChange={setCheckItem} />
        <QuManage ref={quRef} itemId={checkItem?.itemId} />
      </div>
    </div>
  )
})
